__package__ = 'mabledsocli.provider.template.aws.ssm.v1'
from .main import get_default_spec
from .main import AwsSsmTemplateProvider
